==> jc-1.4.0.tar.gz: gnu/java/security/util/Prime.h <==
// public final class gnu.java.security.util.Prime

// class file dependencies
// @dep_class c874a81b06ec8350 gnu_java_security_util_Prime
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_util_Prime_H_
#define _JC_gnu_java_security_util_Prime_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_gnu_java_security_util_Prime$sub_refs	_jc_gnu_java_security_util_Prime$sub_refs;
typedef struct _jc_gnu_java_security_util_Prime$sub_nonrefs	_jc_gnu_java_security_util_Prime$sub_nonrefs;
typedef struct _jc_gnu_java_security_util_Prime$refs	_jc_gnu_java_security_util_Prime$refs;
typedef struct _jc_gnu_java_security_util_Prime$nonrefs	_jc_gnu_java_security_util_Prime$nonrefs;
typedef struct _jc_gnu_java_security_util_Prime$object	_jc_gnu_java_security_util_Prime$object;

typedef const struct _jc_gnu_java_security_util_Prime$vmethods	_jc_gnu_java_security_util_Prime$vmethods;
typedef const struct _jc_gnu_java_security_util_Prime$vtable	_jc_gnu_java_security_util_Prime$vtable;
typedef const struct _jc_gnu_java_security_util_Prime$vtype	_jc_gnu_java_security_util_Prime$vtype;

// Constructors
extern void _jc_gnu_java_security_util_Prime$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_util_Prime$object *);

// Static methods
extern struct _jc_java_math_BigInteger$object *_jc_gnu_java_security_util_Prime$method$generateRandomPrime$11a496f3dc850602(_jc_env *, jint, jint, struct _jc_java_math_BigInteger$object *);
extern struct _jc_java_math_BigInteger$object *_jc_gnu_java_security_util_Prime$method$generateRandomPrime$5e06bbef4754ac69(_jc_env *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, jint, jint, struct _jc_java_math_BigInteger$object *);

// Virtual methods structure
struct _jc_gnu_java_security_util_Prime$vmethods {
};

// Vtable
struct _jc_gnu_java_security_util_Prime$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_util_Prime$vmethods	gnu_java_security_util_Prime;
};

// Vtype
struct _jc_gnu_java_security_util_Prime$vtype {
	_jc_type			type;
	_jc_gnu_java_security_util_Prime$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_util_Prime$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_util_Prime$refs {
    _jc_gnu_java_security_util_Prime$sub_refs	gnu_java_security_util_Prime;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_util_Prime$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_util_Prime$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_util_Prime$sub_nonrefs	gnu_java_security_util_Prime;
};

// Object instance structure
struct _jc_gnu_java_security_util_Prime$object {
	_jc_gnu_java_security_util_Prime$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_util_Prime$vtype	*vtype;
	_jc_gnu_java_security_util_Prime$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_util_Prime$vtype _jc_gnu_java_security_util_Prime$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_util_Prime, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_util_Prime$class_object;

#endif	/* _JC_gnu_java_security_util_Prime_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/util/Prime.h <==
// public final class gnu.java.security.util.Prime

// class file dependencies
// @dep_class c874a81b06ec8350 gnu_java_security_util_Prime
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_util_Prime_H_
#define _JC_gnu_java_security_util_Prime_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_gnu_java_security_util_Prime$sub_refs	_jc_gnu_java_security_util_Prime$sub_refs;
typedef struct _jc_gnu_java_security_util_Prime$sub_nonrefs	_jc_gnu_java_security_util_Prime$sub_nonrefs;
typedef struct _jc_gnu_java_security_util_Prime$refs	_jc_gnu_java_security_util_Prime$refs;
typedef struct _jc_gnu_java_security_util_Prime$nonrefs	_jc_gnu_java_security_util_Prime$nonrefs;
typedef struct _jc_gnu_java_security_util_Prime$object	_jc_gnu_java_security_util_Prime$object;

typedef const struct _jc_gnu_java_security_util_Prime$vmethods	_jc_gnu_java_security_util_Prime$vmethods;
typedef const struct _jc_gnu_java_security_util_Prime$vtable	_jc_gnu_java_security_util_Prime$vtable;
typedef const struct _jc_gnu_java_security_util_Prime$vtype	_jc_gnu_java_security_util_Prime$vtype;

// Constructors
extern void _jc_gnu_java_security_util_Prime$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_util_Prime$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_math_BigInteger$object *_jc_gnu_java_security_util_Prime$method$generateRandomPrime$11a496f3dc850602(_jc_env *, jint, jint, struct _jc_java_math_BigInteger$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_gnu_java_security_util_Prime$method$generateRandomPrime$5e06bbef4754ac69(_jc_env *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, jint, jint, struct _jc_java_math_BigInteger$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_util_Prime$vmethods {
};

// Vtable
struct _jc_gnu_java_security_util_Prime$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_util_Prime$vmethods	gnu_java_security_util_Prime;
};

// Vtype
struct _jc_gnu_java_security_util_Prime$vtype {
	_jc_type			type;
	_jc_gnu_java_security_util_Prime$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_util_Prime$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_util_Prime$refs {
    _jc_gnu_java_security_util_Prime$sub_refs	gnu_java_security_util_Prime;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_util_Prime$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_util_Prime$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_util_Prime$sub_nonrefs	gnu_java_security_util_Prime;
};

// Object instance structure
struct _jc_gnu_java_security_util_Prime$object {
	_jc_gnu_java_security_util_Prime$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_util_Prime$vtype	*vtype;
	_jc_gnu_java_security_util_Prime$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_util_Prime$vtype _jc_gnu_java_security_util_Prime$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_util_Prime, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_util_Prime$class_object;

#endif	/* _JC_gnu_java_security_util_Prime_H_ */
